@@ -16,9 +16,11 @@ from suite_py.lib.handler.youtrack_handler import (
     YoutrackHandler,
     replace_card_names_with_md_links,
 )
+from suite_py.commands.release import _parse_available_countries
 
 
 class Deploy:
+    # pylint: disable=too-many-instance-attributes
     def __init__(self, project, config, tokens):
         self._project = project
         self._config = config
@@ -28,12 +30,19 @@ class Deploy:
         self._repo = self._github.get_repo(project)
         self._git = GitHandler(project, config)
         self._drone = DroneHandler(config, tokens, repo=project)
+        self._countries = _parse_available_countries(self._drone)
 
     def run(self):
         self._stop_if_prod_locked()
 
         self._git.fetch()
 
+        if len(self._countries) > 0:
+            logger.error(
+                "Deploy command cannot be used on this project. Try to run `suite-py release` instead."
+            )
+            sys.exit(1)
+
         tags = self._repo.get_tags()
         tag = git.get_last_tag_number(tags)
         latest_release = self._get_release(tag)
@@ -41,7 +50,7 @@ class Deploy:
         current_version = latest_release.tag_name if latest_release else tag
 
         if current_version:
-            logger.info(f"La release attuale è {current_version}")
+            logger.info(f"The current release is {current_version}")
             versions = _bump_versions(current_version)
             commits = self._github.get_commits_since_release(
                 self._repo, current_version
@@ -53,13 +62,13 @@ class Deploy:
                 ["* " + c.commit.message.splitlines()[0] for c in commits]
             )
 
-            logger.info(f"\nLista dei commit:\n{message}\n")
+            logger.info(f"\nCommits list:\n{message}\n")
 
-            if not prompt_utils.ask_confirm("Vuoi continuare?"):
+            if not prompt_utils.ask_confirm("Do you want to continue?"):
                 sys.exit()
 
             new_version = prompt_utils.ask_choices(
-                "Seleziona versione:",
+                "Select version:",
                 [
                     {"name": f"Patch {versions['patch']}", "value": versions["patch"]},
                     {"name": f"Minor {versions['minor']}", "value": versions["minor"]},
@@ -69,9 +78,9 @@ class Deploy:
 
         else:
             # Se non viene trovata la release e non ci sono tag, viene saltato il check delle migrations e l'update delle card su youtrack
-            logger.warning("Nessun tag trovato, sto per pubblicare il tag 0.1.0")
+            logger.warning("No tags found, I'm about to push the tag 0.1.0")
             if not prompt_utils.ask_confirm(
-                "Sicuro di voler continuare?", default=False
+                "Are you sure you want to continue?", default=False
             ):
                 sys.exit()
             new_version = "0.1.0"
@@ -83,13 +92,13 @@ class Deploy:
     def _stop_if_prod_locked(self):
         request = self._captainhook.status(self._project, "production")
         if request.status_code != 200:
-            logger.error("Impossibile determinare lo stato del lock su master.")
+            logger.error("Unable to determine lock status on master.")
             sys.exit(-1)
 
         request_object = request.json()
         if request_object["locked"]:
             logger.error(
-                f"Il progetto è lockato in produzione da {request_object['by']}. Impossibile continuare."
+                f"The project is locked in production by {request_object['by']}. Unable to continue."
             )
             sys.exit(-1)
 
@@ -105,12 +114,14 @@ class Deploy:
             new_version, new_version, replace_card_names_with_md_links(message)
         )
         if new_release:
-            logger.info(f"La release è stata creata! Link: {new_release.html_url}")
+            logger.info(f"The release has been created! Link: {new_release.html_url}")
 
             build_number = self._drone.get_build_from_tag(new_version)
             if build_number:
                 drone_url = self._drone.get_build_url(build_number)
-                logger.info(f"Puoi seguire il deploy in produzione su {drone_url}")
+                logger.info(
+                    f"You can follow the deployment in production here: {drone_url}"
+                )
 
     def _manage_youtrack_card(self, commits, new_version):
         release_state = self._config.youtrack["release_state"]
@@ -119,35 +130,36 @@ class Deploy:
 
         if len(issue_ids) > 0:
             update_youtrack_state = prompt_utils.ask_confirm(
-                f"Vuoi spostare le card associate in {release_state}?", default=False
+                f"Do you want to move the associated cards to {release_state} state?",
+                default=False,
             )
 
             for issue_id in issue_ids:
                 try:
                     self._youtrack.comment(
                         issue_id,
-                        f"Deploy in produzione di {self._project} effettuato con la release {new_version}",
+                        f"Deploy in production of {self._project} done with the release {new_version}",
                     )
                     if update_youtrack_state:
                         self._youtrack.update_state(issue_id, release_state)
-                        logger.info(f"{issue_id} spostata in {release_state}")
+                        logger.info(f"{issue_id} moved to {release_state}")
                 except Exception:
                     logger.warning(
-                        f"Si è verificato un errore durante lo spostamento della card {issue_id} in {release_state}"
+                        f"An error occurred while moving the card {issue_id} to {release_state}"
                     )
                 repos_status = self._get_repos_status_from_issue(issue_id)
                 if all(r["deployed"] for r in repos_status.values()):
                     try:
                         self._youtrack.update_deployed_field(issue_id)
-                        logger.info("Custom field Deployed aggiornato su YouTrack")
+                        logger.info("Custom field Deployed updated on YouTrack")
                     except Exception:
                         logger.warning(
-                            "Si è verificato un errore durante l'aggiornamento del custom field Deployed"
+                            "An error occurred while updating the custom field Deployed"
                         )
 
     def _get_repos_status_from_issue(self, issue_id):
         regex_pr = r"^PR .* -> https:\/\/github\.com\/primait\/(.*)\/pull\/([0-9]*)$"
-        regex_deploy = r"^Deploy in produzione di (.*) effettuato con la release"
+        regex_deploy = r"^Deploy in production of (.*) done with the release"
         comments = self._youtrack.get_comments(issue_id)
         repos_status = {}
 
@@ -179,7 +191,7 @@ def _bump_versions(current):
 
 def _check_migrations_deploy(commits):
     if not commits:
-        logger.error("ERRORE: nessun commit trovato")
+        logger.error("ERROR: no commit found")
         sys.exit(-1)
     elif len(commits) == 1:
         files_changed = git.files_changed_between_commits("--raw", f"{commits[0].sha}~")
@@ -188,6 +200,8 @@ def _check_migrations_deploy(commits):
             f"{commits[-1].sha}~", commits[0].sha
         )
     if git.migrations_found(files_changed):
-        logger.warning("ATTENZIONE: migrations rilevate nel codice")
-        if not prompt_utils.ask_confirm("Sicuro di voler continuare?", default=False):
+        logger.warning("WARNING: migrations detected in the code")
+        if not prompt_utils.ask_confirm(
+            "Are you sure you want to continue?", default=False
+        ):
             sys.exit()
